pub struct ApigeeLlmParams {
pub model: String,
pub proxy_url: Option<String>,
pub api_key: Option<String>,
}Fields
model: StringThe name of the model to use. The model string specifies the LLM provider (e.g., Vertex AI, Gemini), API version, and the model ID. Supported format: apigee/[<provider>/][<version>/]<model_id> Components: provider (optional): vertex_ai or gemini. version (optional): The API version (e.g., v1, v1beta). If not provided, a default version will selected based on the provider. model_id (required): The model identifier (e.g., gemini-2.5-flash). Examples: - apigee/gemini-2.5-flash - apigee/v1/gemini-2.5-flash - apigee/vertex_ai/gemini-2.5-flash - apigee/gemini/v1/gemini-2.5-flash - apigee/vertex_ai/v1beta/gemini-2.5-flash
proxy_url: Option<String>The proxy URL for the provider API. If not provided, it will look for the APIGEE_PROXY_URL environment variable.
api_key: Option<String>API key to use. If not provided, it will look for the GOOGLE_GENAI_API_KEY or GEMINI_API_KEY environment variable. If gemini provider is selected and no key is provided, the fake key “-” will be used for the “x-goog-api-key” header.