pub struct AuthToolArguments {
pub function_call_id: String,
pub auth_config: Value,
}Expand description
The arguments for the special long running function tool that is used to request end user credentials.
Fields
function_call_id: Stringauth_config: ValueTrait Implementations
Sourceimpl Clone for AuthToolArguments
impl Clone for AuthToolArguments
Sourcefn clone(&self) -> AuthToolArguments
fn clone(&self) -> AuthToolArguments
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuthToolArguments
impl Debug for AuthToolArguments
Sourceimpl Default for AuthToolArguments
impl Default for AuthToolArguments
Sourcefn default() -> AuthToolArguments
fn default() -> AuthToolArguments
Returns the “default value” for a type. Read more