pub struct BaseMemoryService {}Expand description
Base interface for memory services. The service provides functionalities to ingest sessions into memory so that the memory can be used for user queries.