pub struct Event {
pub id: String,
pub invocation_id: String,
pub author: Option<String>,
pub actions: Value,
pub long_running_tool_ids: Option<Vec<String>>,
pub branch: Option<String>,
pub timestamp: f64,
}Expand description
Represents an event in a conversation between agents and users. It is used to store the content of the conversation, as well as the actions taken by the agents like function calls, etc.
Fields
id: StringThe unique identifier of the event. Do not assign the ID. It will be assigned by the session.
invocation_id: StringThe invocation ID of the event. Should be non-empty before appending to a session.
“user” or the name of the agent, indicating who appended the event to the session.
actions: ValueThe actions taken by the agent.
long_running_tool_ids: Option<Vec<String>>Set of ids of the long running function calls. Agent client will know from this field about which function call is long running. Only valid for function call event
branch: Option<String>The branch of the event. The format is like agent_1.agent_2.agent_3, where agent_1 is the parent of agent_2, and agent_2 is the parent of agent_3. Branch is used when multiple sub-agent shouldn’t see their peer agents’ conversation history.
timestamp: f64The timestamp of the event.