pub struct LiveRequest {
pub content: Option<Content>,
pub blob: Option<Blob>,
pub activity_start: Option<ActivityStart>,
pub activity_end: Option<ActivityEnd>,
pub close: Option<bool>,
}Expand description
Request sent to live agents.
Fields
content: Option<Content>If set, send the content to the model in turn-by-turn mode.
blob: Option<Blob>If set, send the blob to the model in realtime mode.
activity_start: Option<ActivityStart>If set, signal the start of user activity to the model.
activity_end: Option<ActivityEnd>If set, signal the end of user activity to the model.
close: Option<bool>If set, close the queue.