pub struct LoopAgentConfig {
pub name: String,
pub max_iterations: Option<f64>,
pub description: Option<String>,
pub parent_agent: Option<Arc<dyn Agent>>,
pub sub_agents: Option<Vec<Arc<dyn Agent>>>,
pub before_agent_callback: Option<Box<dyn Fn(&InvocationContext) + Send + Sync>>,
pub after_agent_callback: Option<Box<dyn Fn(&InvocationContext) + Send + Sync>>,
}Expand description
The configuration options for creating a loop agent. (Inherits fields from BaseAgent)
Fields
name: Stringmax_iterations: Option<f64>The maximum number of iterations the loop agent will run. If not provided, the loop agent will run indefinitely.
description: Option<String>parent_agent: Option<Arc<dyn Agent>>sub_agents: Option<Vec<Arc<dyn Agent>>>before_agent_callback: Option<Box<dyn Fn(&InvocationContext) + Send + Sync>>after_agent_callback: Option<Box<dyn Fn(&InvocationContext) + Send + Sync>>Implementations