pub struct OAuth2Auth {
pub client_id: Option<String>,
pub client_secret: Option<String>,
pub auth_uri: Option<String>,
pub state: Option<String>,
pub redirect_uri: Option<String>,
pub auth_response_uri: Option<String>,
pub auth_code: Option<String>,
pub access_token: Option<String>,
pub refresh_token: Option<String>,
pub expires_at: Option<f64>,
pub expires_in: Option<f64>,
}Expand description
Represents credential value and its metadata for a OAuth2 credential.
Fields
client_id: Option<String>client_secret: Option<String>auth_uri: Option<String>tool or adk can generate the authUri with the state info thus client can verify the state
state: Option<String>redirect_uri: Option<String>tool or adk can decide the redirect_uri if they don’t want client to decide
auth_response_uri: Option<String>auth_code: Option<String>access_token: Option<String>refresh_token: Option<String>expires_at: Option<f64>expires_in: Option<f64>Trait Implementations
Sourceimpl Clone for OAuth2Auth
impl Clone for OAuth2Auth
Sourcefn clone(&self) -> OAuth2Auth
fn clone(&self) -> OAuth2Auth
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OAuth2Auth
impl Debug for OAuth2Auth
Sourceimpl Default for OAuth2Auth
impl Default for OAuth2Auth
Sourcefn default() -> OAuth2Auth
fn default() -> OAuth2Auth
Returns the “default value” for a type. Read more