RunConfig

Struct RunConfig 

pub struct RunConfig {
    pub speech_config: Option<SpeechConfig>,
    pub response_modalities: Option<Vec<Modality>>,
    pub save_input_blobs_as_artifacts: Option<bool>,
    pub support_cfc: Option<bool>,
    pub streaming_mode: Option<Value>,
    pub output_audio_transcription: Option<Value>,
    pub input_audio_transcription: Option<Value>,
    pub enable_affective_dialog: Option<bool>,
    pub proactivity: Option<ProactivityConfig>,
    pub realtime_input_config: Option<RealtimeInputConfig>,
    pub max_llm_calls: Option<f64>,
    pub pause_on_tool_calls: Option<bool>,
}
Configs for runtime behavior of agents.

Fields

speech_config: Option<SpeechConfig>

Speech configuration for the live agent.

response_modalities: Option<Vec<Modality>>

The output modalities. If not set, it’s default to AUDIO.

save_input_blobs_as_artifacts: Option<bool>

Whether or not to save the input blobs as artifacts.

support_cfc: Option<bool>

Whether to support CFC (Compositional Function Calling). Only applicable for StreamingMode.SSE. If it’s true. the LIVE API will be invoked. Since only LIVE API supports CFC WARNING: This feature is experimental and its API or behavior may change in future releases.

streaming_mode: Option<Value>

Streaming mode, None or StreamingMode.SSE or StreamingMode.BIDI.

output_audio_transcription: Option<Value>

Output audio transcription config.

input_audio_transcription: Option<Value>

Input transcription for live agents with audio input from user.

enable_affective_dialog: Option<bool>

If enabled, the model will detect emotions and adapt its responses accordingly.

proactivity: Option<ProactivityConfig>

Configures the proactivity of the model. This allows the model to respond proactively to the input and to ignore irrelevant input.

realtime_input_config: Option<RealtimeInputConfig>

Realtime input config for live agents with audio input from user.

max_llm_calls: Option<f64>

A limit on the total number of llm calls for a given run. Valid Values: - More than 0 and less than sys.maxsize: The bound on the number of llm calls is enforced, if the value is set in this range. - Less than or equal to 0: This allows for unbounded number of llm calls.

pause_on_tool_calls: Option<bool>

If true, the agent loop will suspend on ANY tool call, allowing the client to intercept and execute tools (Client-Side Tool Execution).