pub struct StreamableHTTPConnectionParams {
pub type: String,
pub url: String,
pub header: Option<Value>,
pub timeout: Option<f64>,
pub sse_read_timeout: Option<f64>,
pub terminate_on_close: Option<bool>,
pub transport_options: Option<Value>,
}Expand description
Defines the parameters for establishing a connection to an MCP server over HTTP using Server-Sent Events (SSE) for streaming. Usage: const connectionParams: StreamableHTTPConnectionParams = { type: ‘StreamableHTTPConnectionParams’, url: ‘http://localhost:8788/mcp’ };
Fields
type: Stringurl: Stringheader: Option<Value>Use transportOptions.requestInit.headers instead. This field will be ignored if transportOptions is provided even if no headers are specified in transportOptions.
timeout: Option<f64>sse_read_timeout: Option<f64>terminate_on_close: Option<bool>transport_options: Option<Value>Trait Implementations
Sourceimpl Clone for StreamableHTTPConnectionParams
impl Clone for StreamableHTTPConnectionParams
Sourcefn clone(&self) -> StreamableHTTPConnectionParams
fn clone(&self) -> StreamableHTTPConnectionParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for StreamableHTTPConnectionParams
impl Default for StreamableHTTPConnectionParams
Sourcefn default() -> StreamableHTTPConnectionParams
fn default() -> StreamableHTTPConnectionParams
Returns the “default value” for a type. Read more