pub struct LlmAsJudge { /* private fields */ }Expand description
Evaluator that uses an LLM to judge agent responses.
Sends the actual and expected invocations to an LLM along with a rubric, and parses the score from the LLM’s response.
Implementations
Sourceimpl LlmAsJudge
impl LlmAsJudge
Sourcepub fn new(llm: Arc<dyn BaseLlm>, config: LlmAsJudgeConfig) -> Self
pub fn new(llm: Arc<dyn BaseLlm>, config: LlmAsJudgeConfig) -> Self
Create a new LLM-as-judge evaluator.