MergePolicy

Enum MergePolicy 

pub enum MergePolicy {
    KeepKnown,
    Overwrite,
}
How an extracted field should be merged into authoritative session state.

Variants



KeepKnown

Keep an existing state value; write only when the target key is absent.



Overwrite

Always overwrite the target state key with the extracted field value.