pub enum TransitionEvaluation {
Ready {
target: String,
transition_index: usize,
},
Blocked {
target: String,
transition_index: usize,
missing: Vec<String>,
},
}Expand description
Result of evaluating outbound transitions.
Variants
Ready
A transition can be committed immediately.
Fields
Blocked
A transition guard matched, but the target phase is missing required state that its preparations may be able to materialize.