pub struct VertexAiRagMemoryConfig {
pub corpus: String,
pub project: String,
pub location: String,
pub similarity_top_k: Option<u32>,
pub vector_distance_threshold: Option<f64>,
}Expand description
Configuration for the Vertex AI RAG memory service.
Fields
corpus: StringThe RAG corpus resource name.
Format: projects/{project}/locations/{location}/ragCorpora/{corpus_id}
project: StringGoogle Cloud project ID.
location: StringGoogle Cloud location (e.g. us-central1).
similarity_top_k: Option<u32>Number of contexts to retrieve (maps to similarity_top_k).
vector_distance_threshold: Option<f64>Only return contexts with a vector distance smaller than this threshold.
Implementations
Sourceimpl VertexAiRagMemoryConfig
impl VertexAiRagMemoryConfig
Sourcepub fn from_corpus(corpus: impl Into<String>) -> Self
pub fn from_corpus(corpus: impl Into<String>) -> Self
Create a new config from a corpus resource name, deriving the project / location from it when fully-qualified.