pub struct JoinTextAgent { /* private fields */ }Expand description
Waits for dispatched background tasks and collects their results.
Implementations
Sourceimpl JoinTextAgent
impl JoinTextAgent
Sourcepub fn new(name: impl Into<String>, registry: TaskRegistry) -> Self
pub fn new(name: impl Into<String>, registry: TaskRegistry) -> Self
Create a new join agent that waits for dispatched tasks.
Sourcepub fn with_middleware_chain(self, chain: MiddlewareChain) -> Self
pub fn with_middleware_chain(self, chain: MiddlewareChain) -> Self
Attach a middleware chain. AgentEvent::AgentCompleted is emitted
through it for each task as it is joined successfully, and
AgentEvent::Timeout when a task exceeds the join timeout.