pub struct PreloadMemoryTool;Expand description
Tool that preloads relevant memories into the LLM request context.
Unlike crate::tools::LoadMemoryTool which is called by the model, this tool
automatically injects memories into the system instruction or context
before the model generates a response.
Implementations
Sourceimpl PreloadMemoryTool
impl PreloadMemoryTool
Sourcepub fn process_llm_request(&self, request: &mut LlmRequest, memories: &[String])
pub fn process_llm_request(&self, request: &mut LlmRequest, memories: &[String])
Inject memory context into the LLM request.
Appends memory entries to the system instruction.