is_gemini_model

Function is_gemini_model 

pub fn is_gemini_model(model_string: &str) -> bool
Returns true if the model name starts with "gemini-".

The model name is first extracted from any fully-qualified resource path.