pub struct EventActions {
pub skip_summarization: Option<bool>,
pub state_delta: String,
pub artifact_delta: String,
pub transfer_to_agent: Option<String>,
pub escalate: Option<bool>,
pub requested_auth_configs: String,
pub requested_tool_confirmations: String,
}Expand description
Represents the actions attached to an event.
Fields
skip_summarization: Option<bool>If true, it won’t call model to summarize function response. Only used for function_response event.
state_delta: StringIndicates that the event is updating the state with the given delta.
artifact_delta: StringIndicates that the event is updating an artifact. key is the filename, value is the version.
transfer_to_agent: Option<String>If set, the event transfers to the specified agent.
escalate: Option<bool>The agent is escalating to a higher level agent.
requested_auth_configs: StringAuthentication configurations requested by tool responses. This field will only be set by a tool response event indicating tool request auth credential. - Keys: The function call id. Since one function response event could contain multiple function responses that correspond to multiple function calls. Each function call could request different auth configs. This id is used to identify the function call. - Values: The requested auth config.
requested_tool_confirmations: StringA dict of tool confirmation requested by this event, keyed by the function call id.