pub struct ForwardingArtifactService { /* private fields */ }Expand description
Artifact service that proxies all calls to a parent service. Used by ToolContext to give tools scoped artifact access.
Implementations
Sourceimpl ForwardingArtifactService
impl ForwardingArtifactService
Sourcepub fn new(inner: Arc<dyn ArtifactService>) -> Self
pub fn new(inner: Arc<dyn ArtifactService>) -> Self
Create a new forwarding artifact service wrapping the given inner service.