pub struct HallucinationEvaluator { /* private fields */ }Expand description
Evaluates whether agent responses are grounded (not hallucinated).
Uses an LLM-as-judge to assess whether the model’s claims are supported by the conversation context, tool outputs, and provided information.
Implementations
Sourceimpl HallucinationEvaluator
impl HallucinationEvaluator
Sourcepub fn with_intermediate(self, eval: bool) -> Self
pub fn with_intermediate(self, eval: bool) -> Self
Set whether to evaluate intermediate responses in addition to the final response.
Sourcepub fn with_judge_model(self, model: impl Into<String>) -> Self
pub fn with_judge_model(self, model: impl Into<String>) -> Self
Set an override judge model name.