pub struct BuiltInPlanner { /* private fields */ }Expand description
Built-in planner that leverages the model’s native planning capabilities.
This is a lightweight planner that adds a simple planning instruction to encourage the model to think step-by-step before acting.
Implementations