pub struct PlanReActPlanner { /* private fields */ }Expand description
Plan-ReAct planner that constrains the model to plan before acting.
The model is instructed to use specific tags to separate planning, reasoning, action, and final answer sections. The planner then filters the response to preserve only relevant sections.
Implementations
Sourceimpl PlanReActPlanner
impl PlanReActPlanner
Sourcepub fn with_tool_instructions(self, include: bool) -> Self
pub fn with_tool_instructions(self, include: bool) -> Self
Set whether to include tool use instructions in the planning prompt.